# What does this library ?
It give a very simple way to multitreat process over all your processors.
I use it to treat very large dataset in just-in-time way (cross process stream).

# Licence (TL;DR; version)
This small program is safe to include in your projects, even commercial, and doesn't require to propagate the licence to projects that include it.
Details in the (LICENCE.md)[./LICENCE.md] (MIT licence)

# Get started
This library is very simple.
How have exemple usage in tests, you will figure it out without problem.